.. py:currentmodule:: lsst.utils

.. _lsst.utils:

##########
lsst.utils
##########

The ``lsst.utils`` module provides common code for tests, interfacing between C++ and Python, and debugging.

.. _lsst.utils-changes:

Changes
=======

.. toctree::
   :maxdepth: 1

   CHANGES.rst

.. _lsst.utils-contributing:

Contributing
============

``lsst.utils`` is developed at https://github.com/lsst/utils.
You can find Jira issues for this module under the `utils <https://jira.lsstcorp.org/issues/?jql=project%20%3D%20DM%20AND%20component%20%3D%20utils>`_ component.

.. _lsst.utils-pyapi:

Python API reference
====================

.. automodapi:: lsst.utils
   :no-main-docstr:
.. automodapi:: lsst.utils.tests
   :no-main-docstr:
   :no-inherited-members:
.. automodapi:: lsst.utils.logging
   :no-main-docstr:
.. automodapi:: lsst.utils.iteration
   :no-main-docstr:
.. automodapi:: lsst.utils.classes
   :no-main-docstr:
.. automodapi:: lsst.utils.introspection
   :no-main-docstr:
.. automodapi:: lsst.utils.timer
   :no-main-docstr:
.. automodapi:: lsst.utils.packages
   :no-main-docstr:
.. automodapi:: lsst.utils.usage
   :no-main-docstr:
.. automodapi:: lsst.utils.threads
   :no-main-docstr:
